==> cryptominisat-debug-5.12.1-1-x86_64.pkg.tar.zst: usr/src/debug/cryptominisat/cryptominisat/src/main.h <==
/******************************************
Copyright (C) 2009-2020 Authors of CryptoMiniSat, see AUTHORS file

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
***********************************************/

#ifndef MAIN_H
#define MAIN_H

#include <string>
#include <vector>
#include <memory>
#include <fstream>

#include "argparse.hpp"
#include "main_common.h"
#include "solverconf.h"
#include "cryptominisat.h"

using std::string;
using std::vector;

using namespace CMSat;

class Main: public MainCommon
{
    public:
        Main(int argc, char** argv);
        ~Main()
        {
            delete solver;
            if (fratf) {
                fflush(fratf);
                fclose(fratf);
            }
        }

        void parseCommandLine();
        virtual int solve();

    private:
        //arguments
        int argc;
        char** argv;
        string var_elim_strategy;
        void check_options_correctness();
        void manually_parse_some_options();
        void parse_restart_type();
        void parse_polarity_type();
        void parse_sampling_vars();
        void check_num_threads_sanity(const unsigned thread_num) const;
        argparse::ArgumentParser program = argparse::ArgumentParser("cryptominisat5");

    protected:
        //Options
        virtual void add_supported_options();
        SATSolver* solver = nullptr;

        //File reading
        void readInAFile(SATSolver* solver2, const string& filename);
        void readInStandardInput(SATSolver* solver2);
        void parseInAllFiles(SATSolver* solver2);

        //Helper functions
        void printResultFunc(
            std::ostream* os
            , const bool toFile
            , const lbool ret
        );
        void printVersionInfo();
        int correctReturnValue(const lbool ret) const;
        lbool multi_solutions();
        void ban_found_solution();

        //Config
        std::string debugLib;
        int printResult = true;
        string commandLine;
        uint32_t max_nr_of_solutions = 1;
        bool dont_ban_solutions = false;
        int sql = 0;
        string sqlite_filename;
        uint64_t maxconfl;

        //Sampling vars
        bool only_sampl_solution = false;
        std::string assump_filename;
        vector<Lit> assumps;


        //Files to read & write
        bool fileNamePresent;
        string result_fname;
        string input_file;
        std::ofstream* resultfile = nullptr;

        //Drat checker
        bool clause_ID_needed = false;
};

#endif //MAIN_H

==> cryptominisat-debug-5.13.0-1-x86_64.pkg.tar.zst: usr/src/debug/cryptominisat/cryptominisat/src/main.h <==
/******************************************
Copyright (C) 2009-2020 Authors of CryptoMiniSat, see AUTHORS file

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
***********************************************/

#ifndef MAIN_H
#define MAIN_H

#include <string>
#include <vector>
#include <memory>
#include <fstream>

#include "argparse.hpp"
#include "main_common.h"
#include "solverconf.h"
#include "cryptominisat.h"

using std::string;
using std::vector;

using namespace CMSat;

class Main: public MainCommon
{
    public:
        Main(int argc, char** argv);
        ~Main()
        {
            delete solver;
            if (fratf) {
                fflush(fratf);
                fclose(fratf);
            }
        }

        void parseCommandLine();
        virtual int solve();

    private:
        //arguments
        int argc;
        char** argv;
        string var_elim_strategy;
        void check_options_correctness();
        void manually_parse_some_options();
        void parse_restart_type();
        void parse_polarity_type();
        void parse_sampling_vars();
        void check_num_threads_sanity(const unsigned thread_num) const;
        argparse::ArgumentParser program = argparse::ArgumentParser("cryptominisat",
            SATSolver::get_version_sha1(),
            argparse::default_arguments::help);

    protected:
        //Options
        virtual void add_supported_options();
        SATSolver* solver = nullptr;

        //File reading
        void readInAFile(SATSolver* solver2, const string& filename);
        void readInStandardInput(SATSolver* solver2);
        void parseInAllFiles(SATSolver* solver2);

        //Helper functions
        void printResultFunc(
            std::ostream* os
            , const bool toFile
            , const lbool ret
        );
        void printVersionInfo();
        int correctReturnValue(const lbool ret) const;
        lbool multi_solutions();
        void ban_found_solution();

        //Config
        std::string debugLib;
        int printResult = true;
        string commandLine;
        uint32_t max_nr_of_solutions = 1;
        bool dont_ban_solutions = false;
        int sql = 0;
        string sqlite_filename;
        uint64_t maxconfl;

        //Sampling vars
        std::string assump_filename;
        vector<Lit> assumps;


        //Files to read & write
        bool fileNamePresent;
        string result_fname;
        string input_file;
        std::ofstream* resultfile = nullptr;

        //Drat checker
        bool clause_ID_needed = false;
};

#endif //MAIN_H
